@@ -1,8 +1,7 @@
 # -*- coding: utf-8 -*-
 
 
-from urllib3.exceptions import ProtocolError
-
+from ocp_resources.constants import PROTOCOL_ERROR_EXCEPTION_DICT
 from ocp_resources.resource import NamespacedResource
 from ocp_resources.utils import TimeoutExpiredError, TimeoutSampler
 from ocp_resources.virtual_machine import VirtualMachine
@@ -86,10 +85,10 @@ class VirtualMachineImport(NamespacedResource):
 
     def __init__(
         self,
-        name,
-        namespace,
-        provider_credentials_secret_name,
-        provider_type,
+        name=None,
+        namespace=None,
+        provider_credentials_secret_name=None,
+        provider_type=None,
         provider_credentials_secret_namespace=None,
         client=None,
         teardown=True,
@@ -105,6 +104,7 @@ class VirtualMachineImport(NamespacedResource):
         warm=False,
         finalize_date=None,
         privileged_client=None,
+        yaml_file=None,
     ):
         super().__init__(
             name=name,
@@ -112,6 +112,7 @@ class VirtualMachineImport(NamespacedResource):
             client=client,
             teardown=teardown,
             privileged_client=privileged_client,
+            yaml_file=yaml_file,
         )
         self.vm_id = vm_id
         self.vm_name = vm_name
@@ -141,6 +142,9 @@ class VirtualMachineImport(NamespacedResource):
 
     def to_dict(self):
         res = super().to_dict()
+        if self.yaml_file:
+            return res
+
         spec = res.setdefault("spec", {})
 
         secret = spec.setdefault("providerCredentialsSecret", {})
@@ -221,8 +225,8 @@ class VirtualMachineImport(NamespacedResource):
         samples = TimeoutSampler(
             wait_timeout=timeout,
             sleep=1,
-            exceptions=ProtocolError,
-            func=self.api().get,
+            exceptions_dict=PROTOCOL_ERROR_EXCEPTION_DICT,
+            func=self.api.get,
             field_selector=f"metadata.name=={self.name}",
             namespace=self.namespace,
         )
@@ -260,14 +264,29 @@ class ResourceMapping(NamespacedResource):
 
     api_group = NamespacedResource.ApiGroup.V2V_KUBEVIRT_IO
 
-    def __init__(self, name, namespace, mapping, client=None, teardown=True):
+    def __init__(
+        self,
+        name=None,
+        namespace=None,
+        mapping=None,
+        client=None,
+        teardown=True,
+        yaml_file=None,
+    ):
         super().__init__(
-            name=name, namespace=namespace, client=client, teardown=teardown
+            name=name,
+            namespace=namespace,
+            client=client,
+            teardown=teardown,
+            yaml_file=yaml_file,
         )
         self.mapping = mapping
 
     def to_dict(self):
         res = super().to_dict()
+        if self.yaml_file:
+            return res
+
         for provider, mapping in self.mapping.items():
             res_provider_section = res.setdefault("spec", {}).setdefault(provider, {})
             if mapping.network_mappings is not None:
